.. role:: hidden
    :class: hidden-section

ax.utils
===================================

.. automodule:: ax.utils
.. currentmodule:: ax.utils


Common
---------------

Base
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.base
    :members:
    :undoc-members:
    :show-inheritance:

Constants
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.constants
    :members:
    :undoc-members:
    :show-inheritance:

Decorator
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.decorator
    :members:
    :undoc-members:
    :show-inheritance:

Docutils
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.docutils
    :members:
    :undoc-members:
    :show-inheritance:

Equality
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.equality
    :members:
    :undoc-members:
    :show-inheritance:

Equality
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.executils
    :members:
    :undoc-members:
    :show-inheritance:

Kwargs
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.kwargs
    :members:
    :undoc-members:
    :show-inheritance:

Logger
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.logger
    :members:
    :undoc-members:
    :show-inheritance:

Result
~~~~~~

.. automodule:: ax.utils.common.result
    :members:
    :undoc-members:
    :show-inheritance:

Serialization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.serialization
    :members:
    :undoc-members:
    :show-inheritance:

Testutils
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.testutils
    :members:
    :no-undoc-members:
    :show-inheritance:

Timeutils
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.timeutils
    :members:
    :undoc-members:
    :show-inheritance:

Typeutils
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.typeutils
    :members:
    :undoc-members:
    :show-inheritance:

Typeutils Torch
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.common.typeutils_torch
    :members:
    :undoc-members:
    :show-inheritance:

Flake8 Plugins
---------------

Docstring Checker
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.flake8_plugins.docstring_checker
    :members:
    :undoc-members:
    :show-inheritance:

Measurement
---------------

Synthetic Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.measurement.synthetic_functions
    :members:
    :undoc-members:
    :show-inheritance:

Notebook
---------------

Plotting
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.notebook.plotting
    :members:
    :undoc-members:
    :show-inheritance:

Report
---------------

Render
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.report.render
    :members:
    :undoc-members:
    :show-inheritance:

Sensitivity
---------------

Derivative GP
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.sensitivity.derivative_gp
    :members:
    :undoc-members:
    :show-inheritance:

Derivative Measures
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.sensitivity.derivative_measures
    :members:
    :undoc-members:
    :show-inheritance:

Sobol Measures
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.sensitivity.sobol_measures
    :members:
    :undoc-members:
    :show-inheritance:

Stats
---------------

Statstools
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.stats.statstools
    :members:
    :undoc-members:
    :show-inheritance:

Storage
---------------

Deletion
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.storage.sqa.delete
    :members:
    :undoc-members:
    :show-inheritance:


Testing
---------------

Backend Scheduler
~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.backend_scheduler
    :members:
    :undoc-members:
    :show-inheritance:

Backend Simulator
~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.backend_simulator
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Stubs
~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.benchmark_stubs
    :members:
    :undoc-members:
    :show-inheritance:

Core Stubs
~~~~~~~~~~~

.. automodule:: ax.utils.testing.core_stubs
    :members:
    :undoc-members:
    :show-inheritance:

Modeling Stubs
~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.modeling_stubs
    :members:
    :undoc-members:
    :show-inheritance:


Mocking
~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.mock
    :members:
    :undoc-members:
    :show-inheritance:


Test Init Files
~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.test_init_files
    :members:
    :undoc-members:
    :show-inheritance:

Torch Stubs
~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.torch_stubs
    :members:
    :undoc-members:
    :show-inheritance:

Unittest Conventions
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.unittest_conventions
    :members:
    :undoc-members:
    :show-inheritance:

Utils
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.utils
    :members:
    :undoc-members:
    :show-inheritance:


Test Metrics
---------------

Backend Simulator Map
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.metrics.backend_simulator_map
    :members:
    :undoc-members:
    :show-inheritance:


Branin Backend Map
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.testing.metrics.branin_backend_map
    :members:
    :undoc-members:
    :show-inheritance:


Tutorials
---------------

Neural Net
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.utils.tutorials.cnn_utils
    :members:
    :undoc-members:
    :show-inheritance:
